import shutil
from pathlib import Path
import pkg_resources

def copy_chart(chart_template_path, helmchart_name):
    shutil.copytree(chart_template_path, helmchart_name)

def update_chart(helmchart_name):
    for item in Path(helmchart_name).rglob('*'):
        if item.is_file():
            # updating
            with open(item, 'r') as read_file:
                filedata = read_file.read()
                filedata = filedata.replace('helm_template', helmchart_name)
            with open(item, 'w') as write_file:
                write_file.write(filedata)

chart_template_name = 'templates/helm_template'

def main_helmchart(helmchart_name):
    chart_template_path_content = pkg_resources.resource_filename(__name__, chart_template_name)
    copy_chart(chart_template_path_content, helmchart_name)
    update_chart(helmchart_name)

# main()


import pkg_resources
 
def update_dockerfile(dockerfile_template, new_dockerfile_name, app_port, app_entrypoint):
    # updating
    new_dockerfile_content = pkg_resources.resource_filename(__name__, dockerfile_template)
    with open(new_dockerfile_content, 'r') as read_file:
        filedata = read_file.read()
        filedata = filedata.replace("PORT", app_port)
        filedata = filedata.replace("APP_ENTRY", app_entrypoint)
    with open(new_dockerfile_name, 'w') as write_file:
        write_file.write(filedata)


def main_dockerfile(new_dockerfile_name, dockerfile_template, app_port, app_entrypoint):
    update_dockerfile(dockerfile_template, new_dockerfile_name, app_port, app_entrypoint)

# main()


from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="gensec",
    version="0.0.4",
    packages=find_packages(),
    include_package_data=True,
    description="A Python package for generating secure docker and k8s resources",
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
        "click", 
        "InquirerPy",
    ],
    entry_points={
        "console_scripts": [
            "gensec=gensec.main:main",
        ],
    },
)



import click
from InquirerPy import inquirer
from gensec.commands.set_dockerfile_template import main_dockerfile
from gensec.commands.set_helm_template import main_helmchart

@click.group(invoke_without_command=True)
@click.pass_context
def main(ctx):
    """Generate a secure resource based on the specified type."""
    # Check if no command was invoked
    if ctx.invoked_subcommand is None:
        click.echo("Error: No command provided. Use '--help' to see available commands.", err=True)
        ctx.exit(1)
    
@main.command(name='dockerfile')
@click.option(
    '--langugaue',
    type=str,
    help='Programming language to use. example: python.')
@click.option(
    '--port',
    type=int,
    help='Port number to expose. example: 8080.')
@click.option(
    '--entrypoint',
    help='Entrypoint for the application. example: main.py.')
@click.help_option(
    help="Show help information for this command.")
def dockerfile(langugaue, port, entrypoint):
    """Generate a Dockerfile."""
    if langugaue == None:
        langugaue = inquirer.select(
            message="Please select a programming language:",
            choices=["python"],
            default="python"
        ).execute()

    if entrypoint == None:
        entrypoint = inquirer.text(
            message="Please enter app entry point:",
            default="main.py"
        ).execute()

    if port == None:
        port = inquirer.text(
            message="Please enter the port number:",
            default="8080"
        ).execute()

    new_dockerfile_name = f"{langugaue}_dockerfile"
    dockerfile_template = f"templates/{langugaue}_dockerfile"
    main_dockerfile(new_dockerfile_name, dockerfile_template, port, entrypoint)

@main.command(name='helmchart')
@click.option(
    '--name',
    help='name of the service. example: dummy-app')
@click.help_option(
    help="Show help information for this command.")
def helmchart(name):
    """Generate a HelmChart."""
    if name == None:
        name = inquirer.text(
            message="Please enter a name for the helmchart:",
            default="dummy-app"
        ).execute()
    main_helmchart(name)

@main.command(name='list')
def list_commands():
    """List available commands."""
    click.echo("Available commands:")
    click.echo("  - dockerfile: Generate a Dockerfile.")
    click.echo("  - helmchart: Generate a Helm chart.")
    click.echo("Use '--help' with each command for more details.")

if __name__ == "__main__":
    main()